@@ -2,7 +2,6 @@
 //! algorithm](https://en.wikipedia.org/wiki/A*_search_algorithm).
 
 use indexmap::map::Entry::{Occupied, Vacant};
-use indexmap::IndexMap;
 use num_traits::Zero;
 use std::cmp::Ordering;
 use std::collections::{BinaryHeap, HashSet};
@@ -10,6 +9,7 @@ use std::hash::Hash;
 use std::usize;
 
 use super::reverse_path;
+use crate::directed::FxIndexMap;
 
 /// Compute a shortest path using the [A* search
 /// algorithm](https://en.wikipedia.org/wiki/A*_search_algorithm).
@@ -97,7 +97,7 @@ where
         cost: Zero::zero(),
         index: 0,
     });
-    let mut parents: IndexMap<N, (usize, C)> = IndexMap::new();
+    let mut parents: FxIndexMap<N, (usize, C)> = FxIndexMap::default();
     parents.insert(start.clone(), (usize::max_value(), Zero::zero()));
     while let Some(SmallestCostHolder { cost, index, .. }) = to_see.pop() {
         let successors = {
@@ -188,7 +188,7 @@ where
         cost: Zero::zero(),
         index: 0,
     });
-    let mut parents: IndexMap<N, (HashSet<usize>, C)> = IndexMap::new();
+    let mut parents: FxIndexMap<N, (HashSet<usize>, C)> = FxIndexMap::default();
     parents.insert(start.clone(), (HashSet::new(), Zero::zero()));
     while let Some(SmallestCostHolder {
         cost,
